import Libp2pRequest from './utils/Libp2pRequest.js';
import { pipe } from 'it-pipe';
import toBuffer from 'it-to-buffer';
class Libp2pHttp {
    constructor(node) {
        this.send = async (requestString, data) => {
            let request;
            try {
                request = new Libp2pRequest(requestString);
            }
            catch (error) {
                return {
                    data: '',
                    status: 'error',
                    error: `Invalid request string: ${error.message}`
                };
            }
            const { target, protocol } = request.getComponents();
            const encodedData = typeof data === 'string' ? new TextEncoder().encode(data) : new TextEncoder().encode(JSON.stringify(data));
            try {
                const stream = await this.node.dialProtocol(target, protocol);
                await pipe([encodedData], stream);
                const response = await pipe(stream, async function* (source) {
                    for await (const chunk of source) {
                        yield chunk.subarray();
                    }
                }, toBuffer);
                let decodedResponse;
                try {
                    decodedResponse = new TextDecoder().decode(response);
                    JSON.parse(decodedResponse); // check if the response is a valid JSON
                }
                catch (error) {
                    // It's not a JSON; treat as plain string
                }
                return {
                    data: decodedResponse,
                    status: 'success'
                };
            }
            catch (error) {
                return {
                    data: '',
                    status: 'error',
                    error: `Failed to send request: ${error.message}`
                };
            }
        };
        this.node = node;
    }
    registerHandler(protocol, handlerFunction) {
        this.node.handle(protocol, async ({ stream }) => {
            const requestData = await pipe(stream, async function* (source) {
                for await (const chunk of source) {
                    yield chunk.subarray();
                }
            }, toBuffer);
            let responseData = await handlerFunction(new TextDecoder().decode(requestData));
            if (typeof responseData === 'object' && responseData !== null) {
                responseData = JSON.stringify(responseData);
            }
            else if (typeof responseData !== 'string') {
                responseData = String(responseData);
            }
            await pipe([new TextEncoder().encode(responseData)], stream);
        });
    }
}
Libp2pHttp.init = (node) => {
    const libp2pHttp = new Libp2pHttp(node);
    return libp2pHttp;
};
export default Libp2pHttp;
//# sourceMappingURL=Libp2pHttp.js.map